@@ -54,6 +54,8 @@ class PhaseSpace(object):
                 definition = [ parse_comp(b) for b in definition.split('-')]
             elif ' ' in definition:
                 definition = [ parse_comp(b) for b in definition.split(' ')]
+            else:
+                definition = [ parse_comp(definition) ]
         self.bounds = definition
 
         if load is None:
@@ -515,6 +517,8 @@ class PhaseSpace(object):
         space = set(composition.keys())
         in_phases = []
         for phase in phases:
+            if phase.energy is None:
+                continue
             if phase.space <= space:
                 in_phases.append(phase)
 
@@ -522,6 +526,7 @@ class PhaseSpace(object):
                 mus=mus, phases=in_phases)
 
     def _gclp(self, composition={}, mus={}, phases=[]):
+        print phases
         prob = LpProblem('GibbsEnergyMin', LpMinimize)
         phase_vars = LpVariable.dicts('lib', phases, 0.0)
         prob += lpSum([ (phase.energy -
@@ -540,10 +545,11 @@ class PhaseSpace(object):
         #print composition
         prob.solve()
 
-        E = value(prob.objective)
         xsoln = dict([ (phase, phase_vars[phase].varValue)
             for phase in phases if phase_vars[phase].varValue > 1e-5])
-        return E, xsoln
+        #E = value(prob.objective)
+        energy = sum( p.energy*amt for p, amt in xsoln.items() )
+        return energy, xsoln
 
     def get_minima(self, phases, bounds):
         '''
