@@ -108,8 +108,11 @@ class Composition(models.Model):
         for b in bounds:
             bound = parse_comp(b)
             space |= set(bound.keys())
-        elts = Element.objects.exclude(symbol__in=space)
-        comps = Composition.objects.exclude(element_set__in=elts)
+        in_elts = Element.objects.filter(symbol__in=space)
+        out_elts = Element.objects.exclude(symbol__in=space)
+        comps = Composition.objects.filter(element_set__in=in_elts,
+                ntypes__lt=len(space))
+        comps = Composition.objects.exclude(element_set__in=out_elts)
         comps = comps.exclude(entry=None)
         if calculated:
             comps = comps.exclude(calculation=None)
